program Gibbs_1p3_main

! Clculo de propriedades para reaes qumicas em equilbrio e no-equilbrio
! para o propelente H2/O2

! Implementao da verso atual (1.3):
!      Programador: Carlos Henrique Marchi
!      Local:       LENA/DEMEC/UFPR, Curitiba, PR
!      Perodo:     14 de janeiro a 24 de fevereiro de 2005
!      ltima alterao: 3 de maio de 2005

! Implementao da verso atual (1.2):
!      Programador: Carlos Henrique Marchi
!      Local:       LENA/DEMEC/UFPR, Curitiba, PR
!      Perodo:     10 a 13 de janeiro de 2005
!      ltima alterao: 13 de janeiro de 2005

! Implementao da verso atual (1.1):
!      Programador: Carlos Henrique Marchi
!      Local:       LENA/DEMEC/UFPR, Curitiba, PR
!      Perodo:     7 a 7 de janeiro de 2005
!      ltima alterao: 7 de janeiro de 2005

! Implementao da verso inicial (1.0):
!      Programador: Carlos Henrique Marchi
!      Local:       LENA/DEMEC/UFPR, Curitiba, PR
!      Perodo:     4 a 6 de janeiro de 2005

!-------------------------------------------------------------------------------

! MODELO NUMRICO (resumo):
!   At 8 espcies qumicas disponveis:
!     1 = H2O   2 = O2   3 = H2    4 = OH   
!     5 = O     6 = H    7 = HO2   8 = H2O2
!   Propriedades termodinmicas e de trasnporte so calculadas conforme
!     NASA TM-4513 (1993)
!   O equilbrio qumico  resolvido com o mtodo das constantes de	equilbrio, 
!     que necessita definir as reaes e as espcies envolvidas, e o mtodo de
!     Newton simples para resolver as taxas de dissociao
!   A temperatura de combusto  resolvida com o mtodo da bisseo
!   Linguagem Fortran
!   Aplicativo usado: Microsoft Developer Studio, Fortran PowerStation 4.0
!   Tipo de projeto: Console Application
!   O programa permite resolver 5 tipos de problemas:
!     1 = TERMO: calcular propriedades termodinmicas e de transporte de cada
!                espcie qumica, na base mssica ou molar
!     2 = CONGELADO: calcular propriedades termodinmicas e de transporte de
!                    uma mistura de espcies qumicas
!     3 = EQUILIBRIO: calcular a composio de uma mistura de gases;
!                     h 9 modelos disponveis, com 0 a 18 reaes de
!                     dissociao, envolvendo 3 a 8 espcies qumicas
!     4 = CMARA: calcular a temperatura de combusto e a composio de uma
!                 mistura gases; h 9 modelos disponveis, com 0 a 18 reaes de
!                 dissociao, envolvendo 3 a 8 espcies qumicas
!     5 = TAXA FINITA: calcular a taxa de gerao de massa por unidade de
!                      volume de cada espcie qumica;
!                      h 6 modelos disponveis, com 4 a 18 reaes de
!                      dissociao, envolvendo 6 ou 8 espcies qumicas

! ARQUIVOS envolvidos no programa:
!   Gibbs_1p3_modulo.f90   = sub-rotinas funcionais
!   Gibbs_1p3_main.f90     = programa principal
!   Gibbs_coeficientes_cp_h_g.dat = coeficientes para propriedades termodinmicas
!   Gibbs_coeficientes_ki_mi.dat  = coeficientes para propriedades de transporte
!   Gibbs_1p3.in              = arquivo de dados principal
!   Gibbs_1p3_termo.in        = arquivo de dados do bloco TERMO
!   Gibbs_1p3_congelado.in    = arquivo de dados do bloco CONGELADO
!   Gibbs_1p3_equilibrio.in   = arquivo de dados do bloco EQUILIBRIO
!   Gibbs_1p3_camara.in       = arquivo de dados do bloco CAMARA
!   Gibbs_1p3_taxa_finita.in  = arquivo de dados 1 do bloco TAXA FINITA
!   Gibbs_1p3_taxa_finita2.in = arquivo de dados 2 do bloco TAXA FINITA
!   *.*         = arquivo de sada do programa (nome definido pelo usurio)
!   Notepad.exe = editor de arquivos
!   Gibbs_1p3_LEIA_ME.txt = informaes bsicas sobre o programa
!   Gibbs_1p3.exe         = programa executvel

!-------------------------------------------------------------------------------

use GIBBS_1p3

use PORTLIB

!-------------------------------------------------------------------------------

implicit none

!-------------------------------------------------------------------------------

! *** constantes ***

real*8,parameter :: po = 101325.0d+0 ! presso ao nvel do mar (Pa)

!-------------------------------------------------------------------------------

integer :: calculo ! Tipo de clculo:
                   ! 1=TERMO; 2=CONGELADO; 3=EQUILBRIO; 4=CMARA; 5=TAXA FINITA


integer :: N       ! nmero de espcies qumicas

integer :: base    ! base das propriedades: 1=mssica; 2=molar

integer :: i       ! nmero da espcie qumica
                   ! 1 = H2O   2 = O2   3 = H2    4 = OH   
                   ! 5 = O     6 = H    7 = HO2   8 = H2O2

real*8  :: T       ! temperatura (K)

real*8  :: p       ! presso (atm)

real*8  :: p_si    ! presso (Pa)

real*8  :: OF      ! razo em massa oxidante/combustvel (adim.)

real*8  :: tol_e   ! tolerncia para resolver e(j)

real*8  :: tol_n   ! tolerncia para resolver n

real*8  :: tol_Tc  ! tolerncia para obter Tc

integer :: itimax  ! nmero mximo de iteraes para resolver e(j)

integer :: itemax  ! nmero mximo de iteraes para resolver n

integer :: itcmax  ! nmero mximo de iteraes para resolver Tc

integer :: modelo  ! nmero do modelo de reaes em equilbrio qumico

real*8  :: T_O     ! temperatura de injeo do oxidante na cmara (K)

real*8  :: T_F     ! temperatura de injeo do combustvel na cmara (K)

real*8  :: h_O     ! entalpia de injeo do oxidante na cmara (J/mol)

real*8  :: h_F     ! entalpia de injeo do combustvel na cmara (J/mol)

integer :: tipo_hr ! tipo de HR: 1=automtico; 2=prescrito

integer :: sai     ! =1, escreve variveis secundrias durante as iteraes

real*8,dimension(:),allocatable :: ni   ! nmero de moles (mol)

integer, parameter :: in   =  7 ! nmero do arquivo de entrada (dados)
integer, parameter :: out  = 10 ! nmero do arquivo de sada principal

character*50  :: caso      ! nome do arquivo de sada
character*90  :: titulo    ! ttulo do grfico
character*90  :: note_caso ! notepad + caso
integer       :: dos       ! acessa prompt dos

integer :: k      ! auxiliar

integer :: repete ! nmero de repeties dos clculos para medir tcpu

real*8  :: tcpu   ! tempo de processamento (s)

!-------------------------------------------------------------------------------

! leitura dos dados

  dos = system('notepad Gibbs_1p3.in') ! lista dados

  open(in,file='Gibbs_1p3.in')

    read(in,*) calculo
    read(in,*) repete

  close(in)

  select case ( calculo )

    case ( 1 )
               dos = system('notepad Gibbs_1p3_Termo.in') ! lista dados
               open(in,file='Gibbs_1p3_Termo.in')
               read(in,*) caso
               read(in,*) N
               read(in,*) base
               read(in,*) T

    case ( 2 )
               dos = system('notepad Gibbs_1p3_Congelado.in') ! lista dados
               open(in,file='Gibbs_1p3_Congelado.in')
               read(in,*) caso
               read(in,*) N
               read(in,*) T
               allocate ( ni(N) )
               do i = 1, N
                  read(in,*) ni(i)
               end do

    case ( 3 )
               dos = system('notepad Gibbs_1p3_Equilibrio.in') ! lista dados
               open(in,file='Gibbs_1p3_Equilibrio.in')
               read(in,*) caso
               read(in,*) T
               read(in,*) p_si
               read(in,*) OF
               read(in,*) sai
               read(in,*) itimax
               read(in,*) tol_e
               read(in,*) itemax
               read(in,*) tol_n
               read(in,*) modelo

    case ( 4 )
               dos = system('notepad Gibbs_1p3_Camara.in') ! lista dados
               open(in,file='Gibbs_1p3_Camara.in')
               read(in,*) caso
               read(in,*) p_si
               read(in,*) OF
               read(in,*) sai
               read(in,*) itimax
               read(in,*) tol_e
               read(in,*) itemax
               read(in,*) tol_n
               read(in,*) itcmax
               read(in,*) tol_Tc
               read(in,*) tipo_hr
               read(in,*) T_O
               read(in,*) T_F
               read(in,*) h_O
               read(in,*) h_F
               read(in,*) modelo

    case ( 5 )
               dos = system('notepad Gibbs_1p3_Taxa_Finita.in') ! lista dados
               open(in,file='Gibbs_1p3_Taxa_Finita.in')
               read(in,*) caso
               read(in,*) T
               read(in,*) p_si
               read(in,*) sai
               read(in,*) modelo

    end select

    read(in,*) titulo
  
  close(in)

  p = p_si / po

!-------------------------------------------------------------------------------

! abertura do arquivo de sada

  open(out,file=caso)

  k = len(trim(adjustl(titulo)))

  write(out,1) trim(adjustl(titulo)), caso

  1 format(/, &
        7x, 'ttulo = ', a<k>,//, &
       23x, 'caso = ', a50        )

!-------------------------------------------------------------------------------

! clculos

  select case ( calculo )

    case ( 1 )
               call GIBBS_TERMO_executa

    case ( 2 )
               call GIBBS_CONGELADO_executa

    case ( 3 )
               call GIBBS_EQUILIBRIO_executa

    case ( 4 )
               call GIBBS_CAMARA_executa

    case ( 5 )
               call GIBBS_TAXA_FINITA_executa

    end select
  
!-------------------------------------------------------------------------------

  write(out,2) tcpu
  2 format(/, f14.3, ' = tempo de processamento (segundos)')

  close (out)

  note_caso = 'notepad '//caso

  dos = system(note_caso) ! lista arquivo de resultados


!-------------------------------------------------------------------------------


contains


!-------------------------------------------------------------------------------
 
  subroutine GIBBS_TERMO_executa

    call GIBBS_TERMO_dados_recebe ( out, N, base, T )
  
    call GIBBS_TERMO_dados_escreve ( out )

    call GIBBS_le_coeficientes_cp_h_g

    call GIBBS_escreve_coeficientes_cp_h_g ( out )

    ! cpi
    call GIBBS_cpi_aloca_memoria
    if ( base == 1 ) then
       call GIBBS_cpi_massa_calculo
    else
       call GIBBS_cpi_molar_calculo
    end if
    call GIBBS_cpi_escreve ( out )
    call GIBBS_cpi_fecha_memoria

    ! hi
    call GIBBS_hi_aloca_memoria
    if ( base == 1 ) then
       call GIBBS_hi_massa_calculo
    else
       call GIBBS_hi_molar_calculo
    end if
    call GIBBS_hi_escreve ( out )
    call GIBBS_hi_fecha_memoria

    ! gi
    call GIBBS_gi_aloca_memoria
    if ( base == 1 ) then
       call GIBBS_gi_massa_calculo
    else
       call GIBBS_gi_molar_calculo
    end if
    call GIBBS_gi_escreve ( out )
    call GIBBS_gi_fecha_memoria

    call GIBBS_le_coeficientes_ki_mii

    call GIBBS_escreve_coeficientes_ki_mii ( out )

    ! mii
    call GIBBS_mii_aloca_memoria
    call GIBBS_mii_calculo
    call GIBBS_mii_escreve ( out )
    call GIBBS_mii_fecha_memoria

    ! ki
    call GIBBS_ki_aloca_memoria
    call GIBBS_ki_calculo
    call GIBBS_ki_escreve ( out )
    call GIBBS_ki_fecha_memoria

    call GIBBS_fecha_memoria_ca_especie_Moli
    call GIBBS_fecha_memoria_cb_cc

  end subroutine GIBBS_TERMO_executa

!-------------------------------------------------------------------------------

  subroutine GIBBS_CONGELADO_executa

    call GIBBS_CONGELADO_dados_recebe ( out, N, T, ni )

    call GIBBS_CONGELADO_dados_escreve ( out )

    call GIBBS_CONGELADO_calculos1

    call GIBBS_CONGELADO_escreve1 ( out )

    call GIBBS_Yi_escreve ( out )

    call GIBBS_mi_kc_inicio

    call GIBBS_CONGELADO_calculos2

    call GIBBS_CONGELADO_escreve2 ( out )

    call GIBBS_Xi_escreve ( out )

  end subroutine GIBBS_CONGELADO_executa

!-------------------------------------------------------------------------------
 
  subroutine GIBBS_EQUILIBRIO_executa

    call GIBBS_EQUILIBRIO_dados_recebe ( out,   sai,   modelo, itimax, itemax, &
                                         tol_e, tol_n, T,      p,      OF      )

    call GIBBS_EQUILIBRIO_inicio1

    call GIBBS_EQUILIBRIO_dados_escreve ( out )

    tcpu = timef()

    do k = 1, repete

       call GIBBS_EQUILIBRIO_calculos1

    end do

    tcpu = timef()

    call GIBBS_EQUILIBRIO_escreve1

    call GIBBS_EQUILIBRIO_calculos2

    call GIBBS_EQUILIBRIO_escreve2

    call GIBBS_Ci_aloca_memoria

    call GIBBS_EQUILIBRIO_calculos3

    call GIBBS_EQUILIBRIO_escreve3

  end subroutine GIBBS_EQUILIBRIO_executa

!-------------------------------------------------------------------------------
 
  subroutine GIBBS_CAMARA_executa

    call GIBBS_CAMARA_dados_recebe ( out,    sai,    modelo, tipo_hr, itimax, &
                                     itemax, itcmax, tol_e,  tol_n,   tol_Tc, &
                                     T_O,    T_F,    h_O,    h_F,     p,      OF )

    call GIBBS_CAMARA_inicio

    call GIBBS_CAMARA_dados_escreve ( out )

    tcpu = timef()

    do k = 1, repete

       call GIBBS_CAMARA_calculos1

    end do

    tcpu = timef()

    call GIBBS_EQUILIBRIO_escreve1

    call GIBBS_EQUILIBRIO_calculos2

    call GIBBS_EQUILIBRIO_escreve2

    call GIBBS_Ci_aloca_memoria

    call GIBBS_EQUILIBRIO_calculos3

    call GIBBS_EQUILIBRIO_escreve3
   
    call GIBBS_CAMARA_escreve ( out )

  end subroutine GIBBS_CAMARA_executa

!-------------------------------------------------------------------------------
 
  subroutine GIBBS_TAXA_FINITA_executa

    call GIBBS_TAXA_FINITA_dados_recebe ( out, sai, modelo, T, p )

    call GIBBS_TAXA_FINITA_inicio

    call GIBBS_TAXA_FINITA_dados_escreve ( out )

    call GIBBS_escreve_coeficientes_cp_h_g ( out )

    call GIBBS_TAXA_FINITA_calculos1

    call GIBBS_TAXA_FINITA_escreve1

    tcpu = timef()

    do k = 1, repete

       call GIBBS_TAXA_FINITA_calculos2

    end do

    tcpu = timef()

    call GIBBS_TAXA_FINITA_escreve2

  end subroutine GIBBS_TAXA_FINITA_executa

!-------------------------------------------------------------------------------

end program
